from Plugins.Plugin import PluginDescriptor
from Components.ActionMap import ActionMap
from Components.MenuList import MenuList
from Screens.Screen import Screen
from Screens.Console import Console
from Screens.MessageBox import MessageBox
from enigma import getDesktop
import os
import sys
import threading, subprocess
import re
import time
import serial

sedusetuptool_version = "1.0"

sz_w = getDesktop(0).size().width()

class SEDUSetupTool(Screen):
	if sz_w == 2560:
		skin = """
		<screen position="center,center" size="900,860" title="SEDU Setup Tool Menu" >
			<eLabel font="Regular;44" foregroundColor="white" name="" position="10,772" size="280,80" text="Exit" valign="center" halign="center" backgroundColor="#9f1313" shadowColor="black" shadowOffset="-2,-2" transparent="1" />
			<widget name="menu" position="20,20" size="900,720" scrollbarMode="showOnDemand" />
			<eLabel name="" position="20,760" size="860,4" backgroundColor="grey" />
		</screen>"""
	elif sz_w == 1920:
		skin = """
		<screen position="center,center" size="750,650" title="SEDU Setup Tool Menu" >
			<eLabel font="Regular;30" foregroundColor="white" name="" position="5,624" size="140,40" text="Exit" valign="center" halign="center" backgroundColor="#9f1313" shadowColor="black" shadowOffset="-2,-2" transparent="1" />
			<widget name="menu" position="10,10" size="730,590" scrollbarMode="showOnDemand" />
			<eLabel name="" position="10,610" size="730,2" backgroundColor="grey" />
		</screen>"""
	else:
		skin = """
		<screen position="center,center" size="450,430" title="SEDU Setup Tool Menu" >
			<eLabel font="Regular;22" foregroundColor="white" name="" position="5,386" size="140,40" text="Exit" valign="center" halign="center" backgroundColor="#9f1313" shadowColor="black" shadowOffset="-2,-2" transparent="1" />
			<widget name="menu" position="10,10" size="450,360" scrollbarMode="showOnDemand" />
			<eLabel name="" position="10,380" size="430,2" backgroundColor="grey" />
		</screen>"""
	
	def __init__(self, session, args=None):
		Screen.__init__(self, session)
		self.session = session
		self.menu = args
		list = []
		list.append((_("Set Colororder RBG"), "rbg"))
		list.append((_("Set Effect None"), "none"))
		list.append((_("Set Effect RedWave"), "redwave"))
		list.append((_("Set Effect RandomFader"), "randomfader"))
		list.append((_("Set Effect ColorWave"), "colorWave"))
		list.append((_("Set Effect DIYFader"), "diyfader"))
		list.append((_("Set Effect Blob"), "blob"))
		list.append((_("Set Effect BlobPastell"), "blobpastell"))
		list.append((_("Set Effect GlitterWhite"), "glitterwhite"))
		list.append((_("Set Effect GlitterDark"), "glitterdark"))
		list.append((_("Set Effect Fire"), "fire"))
		list.append((_("Set Effect Spark"), "spark"))
		list.append((_("Save EEPROM"), "save"))
		list.append((_("about SEDU Setup Tool plugin"), "about"))
		self["menu"] = MenuList(list)
		self["actions"] = ActionMap(["OkCancelActions"], {"ok": self.run, "cancel": self.close}, -1)
		
		self.onShown.append(self.checkttyUSB)
		self.firstrun = True
	
	def checkttyUSB(self):
		if self.firstrun:
			self.firstrun=False
			if os.path.exists('/dev/ttyUSB0'):
				ttyUSB = "/dev/ttyUSB0"
			elif os.path.exists('/dev/ttyUSB1'):
				ttyUSB = "/dev/ttyUSB1"
			else:
				self.session.open(MessageBox,"Error: no ttyUSB found!\n\nPlease connect your SEDU-Lights Box to USB", MessageBox.TYPE_INFO,timeout=5)
				self.close()
				return
		
			try:
				self.ser = serial.Serial(ttyUSB, 500000)
			except serial.SerialException:
				serial.Serial(ttyUSB, 500000).close()
				self.ser = serial.Serial(ttyUSB, 500000)
				
			try:
				print ("------ Serial port is open! ------")
				ser.isOpen()
			except Exception:
				print ("!!!!!! error open serial port: !!!!!!")
		
	def run(self):
		returnValue = self["menu"].l.getCurrentSelection()[1]
		if returnValue is not None:
			command = ""
			if returnValue is "rbg":
				command = b'\xA5\x5A\xFF\xC0\x04\xFF\x00\x00\xFF\x0A\x02\x01\x0D'
			elif returnValue is "none":
				command = b'\xA5\x5A\xFF\xC0\x00\xFF\x00\x00\xFF\x0A\x02\x01\x0D'
			elif returnValue is "redwave":
				command = b'\xA5\x5A\xFF\xC0\x05\xFF\x00\x00\xFF\x0A\x02\x01\x0D'
			elif returnValue is "randomfader":
				command = b'\xA5\x5A\xFF\xC0\x03\xFF\x00\x00\xFF\x0A\x02\x01\x0D'
			elif returnValue is "colorWave":
				command = b'\xA5\x5A\xFF\xC0\x06\x00\x00\xFF\xFF\x0A\x02\x01\x0D'
			elif returnValue is "diyfader":
				command = b'\xA5\x5A\xFF\xC0\x04\xFF\x00\x00\xFF\x0A\x02\x01\x0D'
			elif returnValue is "blob":
				command = b'\xA5\x5A\xFF\xC0\x07\xFF\x00\x00\xFF\x0A\x02\x01\x0D'
			elif returnValue is "blobpastell":
				command = b'\xA5\x5A\xFF\xC0\x08\xFF\x00\x00\xFF\x0A\x02\x01\x0D'
			elif returnValue is "glitterwhite":
				command = b'\xA5\x5A\xFF\xC0\x09\xFF\x00\x00\xFF\x0A\x02\x01\x0D'
			elif returnValue is "glitterdark":
				command = b'\xA5\x5A\xFF\xC0\x0A\xFF\x00\x00\xFF\x0A\x02\x01\x0D'
			elif returnValue is "fire":
				command = b'\xA5\x5A\xFF\xC0\x0B\xFF\x00\x00\xFF\x0A\x02\x01\x0D'
			elif returnValue is "spark":
				command = b'\xA5\x5A\xFF\xC0\x0C\xFF\x00\x00\xFF\x0A\x02\x01\x0D'
			elif returnValue is "save":
				command = b'\xA5\x5A\xFF\xC2\xA5\x0D'
			elif returnValue is "about":
				title="SEDU Setup Tool version %s \nfor Insanelight Plug&Play Set\n\nby pclin 2020\n\nThanks to Sven H and Murxer for the help and testing" % sedusetuptool_version
				self.session.open(MessageBox,("%s") % (title),  MessageBox.TYPE_INFO)
			
			if command:
				cmd = "pidof enigmalight"
				#os.system(cmd)
				try:
					retValue = subprocess.check_output(cmd, stderr=subprocess.STDOUT, shell=True)
				except subprocess.CalledProcessError as error:
					#print ("error", str(error))
					retValue = "" #if pid not found get an error
				print ("retValue of pidof enigmalight", str(retValue))
				if retValue:
					self.session.openWithCallback(self.killallEnigmalight, MessageBox,_("Enigmalight is activ\n\nShutdown Enigmalight?"), MessageBox.TYPE_YESNO,default=True)
				else:
					try:
						self.ser.write (command)
						print("------ serial port is open")
					except Exception:
						print ("!!!!!! error communicating...: ")
						self.session.open(MessageBox, "!!! error communicating with SEDU-Lights!!!\n\n Please reload Plugin", MessageBox.TYPE_INFO)
						self.close()

	def killallEnigmalight(self, ret):
		if ret:
			cmd = "pidof enigmalight > /dev/null 2>&1 && killall -9 enigmalight"
			os.system(cmd)
			self.run()

def main(session, **kwargs):
	session.open(SEDUSetupTool)
	
def Plugins(path,**kwargs):
	return [PluginDescriptor(
		name=_("SEDUSetupTool"), 
		description="Sedu Setup Tool (v%s)" % sedusetuptool_version,
		where = PluginDescriptor.WHERE_PLUGINMENU,icon="plugin.png",
		fnc = main
		),
	PluginDescriptor(name=_("SEDUSetupTool"), where = PluginDescriptor.WHERE_EXTENSIONSMENU, fnc=main)]
